@@ -25,7 +25,7 @@
 
 #include "entry.h"
 
-#include "libkitenexport.h"
+#include "kiten_export.h"
 
 #include <QHash>
 #include <QList>
